@@ -4,6 +4,7 @@ from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import Max, Min, F
 from django.utils.translation import ugettext as _
+import six
 
 
 class OrderedModelBase(models.Model):
@@ -23,7 +24,7 @@ class OrderedModelBase(models.Model):
         abstract = True
 
     def _get_order_with_respect_to(self):
-        if type(self.order_with_respect_to) is str:
+        if isinstance(self.order_with_respect_to, six.string_types):
             self.order_with_respect_to = (self.order_with_respect_to,)
         if self.order_with_respect_to is None:
             raise AssertionError(('ordered model admin "{0}" has not specified "order_with_respect_to"; note that this '
@@ -52,8 +53,12 @@ class OrderedModelBase(models.Model):
 
     def delete(self, *args, **kwargs):
         qs = self.get_ordering_queryset()
+        update_kwargs = {self.order_field_name: F(self.order_field_name) - 1}
+        extra = kwargs.pop('extra_update', None)
+        if extra:
+            update_kwargs.update(extra) 
         qs.filter(**{self.order_field_name + '__gt': getattr(self, self.order_field_name)})\
-          .update(**{self.order_field_name: F(self.order_field_name) - 1})
+          .update(**update_kwargs)
         super(OrderedModelBase, self).delete(*args, **kwargs)
 
     def _move(self, up, qs=None):
@@ -116,7 +121,7 @@ class OrderedModelBase(models.Model):
             return
         if not self._valid_ordering_reference(replacement):
             raise ValueError(
-                "%r can only be swapped with instances of %r with equal %s fields." % (
+                "{0!r} can only be swapped with instances of {1!r} with equal {2!s} fields.".format(
                     self, self.__class__, ' and '.join(["'{}'".format(o[0]) for o in self._get_order_with_respect_to()])
                 )
             )
@@ -140,7 +145,7 @@ class OrderedModelBase(models.Model):
         """
         self.swap(self.get_ordering_queryset().filter(**{self.order_field_name + '__gt': getattr(self, self.order_field_name)}))
 
-    def to(self, order):
+    def to(self, order, extra_update=None):
         """
         Move object to a certain position, updating all affected objects to move accordingly up or down.
         """
@@ -149,23 +154,29 @@ class OrderedModelBase(models.Model):
             return
         qs = self.get_ordering_queryset()
         if getattr(self, self.order_field_name) > order:
+            update_kwargs = {self.order_field_name: F(self.order_field_name) + 1}
+            if extra_update:
+                update_kwargs.update(extra_update)
             qs.filter(**{self.order_field_name + '__lt': getattr(self, self.order_field_name),
                          self.order_field_name + '__gte': order})\
-              .update(**{self.order_field_name: F(self.order_field_name) + 1})
+              .update(**update_kwargs)
         else:
+            update_kwargs = {self.order_field_name: F(self.order_field_name) - 1}
+            if extra_update:
+                update_kwargs.update(extra_update)
             qs.filter(**{self.order_field_name + '__gt': getattr(self, self.order_field_name),
                          self.order_field_name + '__lte': order})\
-              .update(**{self.order_field_name: F(self.order_field_name) - 1})
+              .update(**update_kwargs)
         setattr(self, self.order_field_name, order)
         self.save()
 
-    def above(self, ref):
+    def above(self, ref, extra_update=None):
         """
         Move this object above the referenced object.
         """
         if not self._valid_ordering_reference(ref):
             raise ValueError(
-                "%r can only be swapped with instances of %r with equal %s fields." % (
+                "{0!r} can only be swapped with instances of {1!r} with equal {2!s} fields.".format(
                     self, self.__class__, ' and '.join(["'{}'".format(o[0]) for o in self._get_order_with_respect_to()])
                 )
             )
@@ -178,15 +189,15 @@ class OrderedModelBase(models.Model):
                     .filter(**{self.order_field_name + '__lt': getattr(ref, self.order_field_name)})\
                     .aggregate(Max(self.order_field_name))\
                     .get(self.order_field_name + '__max') or 0
-        self.to(o)
+        self.to(o, extra_update=extra_update)
 
-    def below(self, ref):
+    def below(self, ref, extra_update=None):
         """
         Move this object below the referenced object.
         """
         if not self._valid_ordering_reference(ref):
             raise ValueError(
-                "%r can only be swapped with instances of %r with equal %s fields." % (
+                "{0!r} can only be swapped with instances of {1!r} with equal {2!s} fields.".format(
                     self, self.__class__, ' and '.join(["'{}'".format(o[0]) for o in self._get_order_with_respect_to()])
                 )
             )
@@ -199,21 +210,21 @@ class OrderedModelBase(models.Model):
                     .get(self.order_field_name + '__min') or 0
         else:
             o = getattr(ref, self.order_field_name)
-        self.to(o)
+        self.to(o, extra_update=extra_update)
 
-    def top(self):
+    def top(self, extra_update=None):
         """
         Move this object to the top of the ordered stack.
         """
         o = self.get_ordering_queryset().aggregate(Min(self.order_field_name)).get(self.order_field_name + '__min')
-        self.to(o)
+        self.to(o, extra_update=extra_update)
 
-    def bottom(self):
+    def bottom(self, extra_update=None):
         """
         Move this object to the bottom of the ordered stack.
         """
         o = self.get_ordering_queryset().aggregate(Max(self.order_field_name)).get(self.order_field_name + '__max')
-        self.to(o)
+        self.to(o, extra_update=extra_update)
 
 
 class OrderedModel(OrderedModelBase):
